@@ -114,7 +114,7 @@ class GroupBaseOxmlElement(BaseOxmlElement):
         return None
 
     @lazyproperty
-    def drawing_relative_from(self):
+    def drawing_vertical_relative_from(self):
         if self.alternate is not None:
             try:
                 return self.alternate.choice.drawing.anchor.positionV.relativeFrom
@@ -122,13 +122,30 @@ class GroupBaseOxmlElement(BaseOxmlElement):
                 return None
         return None
 
+    @lazyproperty
+    def drawing_horizontal_relative_from(self):
+        if self.alternate is not None:
+            try:
+                return self.alternate.choice.drawing.anchor.positionH.relativeFrom
+            except:
+                return None
+        return None
+
     @lazyproperty
     def mso_position_vertical_relative(self):
         # Vertical distance relative position
         if isinstance(self.parent, GroupBaseOxmlElement):
-            return self.style.get('mso_position_vertical_relative') or self.drawing_relative_from or \
+            return self.style.get('mso_position_vertical_relative') or self.drawing_vertical_relative_from or \
                    self.parent.mso_position_vertical_relative
-        return self.style.get('mso_position_vertical_relative') or self.drawing_relative_from
+        return self.style.get('mso_position_vertical_relative') or self.drawing_vertical_relative_from
+
+    @lazyproperty
+    def mso_position_horizontal_relative(self):
+        # Vertical distance relative position
+        if isinstance(self.parent, GroupBaseOxmlElement):
+            return self.style.get('mso_position_horizontal_relative') or self.drawing_horizontal_relative_from or \
+                   self.parent.mso_position_horizontal_relative
+        return self.style.get('mso_position_horizontal_relative') or self.drawing_horizontal_relative_from
 
     def _get_width_value(self, key):
         if value := self.style.get(key):
